# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'qt5.ui'
#
# Created by: PyQt5 UI code generator 5.13.2
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_WEnux(object):
    def setupUi(self, WEnux):
        WEnux.setObjectName("WEnux")
        WEnux.resize(983, 865)
        WEnux.setAcceptDrops(False)
        self.centralwidget = QtWidgets.QWidget(WEnux)
        self.centralwidget.setObjectName("centralwidget")
        self.submitButton = QtWidgets.QPushButton(self.centralwidget)
        self.submitButton.setGeometry(QtCore.QRect(850, 770, 104, 36))
        self.submitButton.setObjectName("submitButton")
        self.interfaceBox = QtWidgets.QComboBox(self.centralwidget)
        self.interfaceBox.setGeometry(QtCore.QRect(100, 30, 126, 37))
        self.interfaceBox.setObjectName("interfaceBox")
        self.interfaceLabel = QtWidgets.QLabel(self.centralwidget)
        self.interfaceLabel.setGeometry(QtCore.QRect(20, 40, 67, 19))
        self.interfaceLabel.setObjectName("interfaceLabel")
        self.directionLabel = QtWidgets.QLabel(self.centralwidget)
        self.directionLabel.setGeometry(QtCore.QRect(260, 40, 67, 19))
        self.directionLabel.setObjectName("directionLabel")
        self.debugBox = QtWidgets.QCheckBox(self.centralwidget)
        self.debugBox.setGeometry(QtCore.QRect(620, 780, 95, 25))
        self.debugBox.setObjectName("debugBox")
        self.outputBrowser = QtWidgets.QTextBrowser(self.centralwidget)
        self.outputBrowser.setGeometry(QtCore.QRect(40, 620, 881, 141))
        self.outputBrowser.setObjectName("outputBrowser")
        self.horizontalLayoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.horizontalLayoutWidget.setGeometry(QtCore.QRect(40, 280, 881, 161))
        self.horizontalLayoutWidget.setObjectName("horizontalLayoutWidget")
        self.tcBox = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget)
        self.tcBox.setContentsMargins(0, 0, 0, 0)
        self.tcBox.setObjectName("tcBox")
        self.reorderBox = QtWidgets.QGroupBox(self.horizontalLayoutWidget)
        self.reorderBox.setObjectName("reorderBox")
        self.formLayoutWidget_4 = QtWidgets.QWidget(self.reorderBox)
        self.formLayoutWidget_4.setGeometry(QtCore.QRect(10, 21, 243, 92))
        self.formLayoutWidget_4.setObjectName("formLayoutWidget_4")
        self.formLayout_5 = QtWidgets.QFormLayout(self.formLayoutWidget_4)
        self.formLayout_5.setContentsMargins(0, 0, 0, 0)
        self.formLayout_5.setObjectName("formLayout_5")
        self.reorderName = QtWidgets.QLabel(self.formLayoutWidget_4)
        self.reorderName.setStatusTip("")
        self.reorderName.setObjectName("reorderName")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.reorderName)
        self.reorderValue = QtWidgets.QSpinBox(self.formLayoutWidget_4)
        self.reorderValue.setToolTip("")
        self.reorderValue.setMaximum(100)
        self.reorderValue.setSingleStep(1)
        self.reorderValue.setProperty("value", 0)
        self.reorderValue.setObjectName("reorderValue")
        self.formLayout_5.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.reorderValue)
        self.reorder_correlationName = QtWidgets.QLabel(self.formLayoutWidget_4)
        self.reorder_correlationName.setStatusTip("")
        self.reorder_correlationName.setObjectName("reorder_correlationName")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.reorder_correlationName)
        self.reorder_correlationValue = QtWidgets.QSpinBox(self.formLayoutWidget_4)
        self.reorder_correlationValue.setToolTip("")
        self.reorder_correlationValue.setMaximum(100)
        self.reorder_correlationValue.setSingleStep(1)
        self.reorder_correlationValue.setProperty("value", 0)
        self.reorder_correlationValue.setObjectName("reorder_correlationValue")
        self.formLayout_5.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.reorder_correlationValue)
        self.tcBox.addWidget(self.reorderBox)
        self.rateBox = QtWidgets.QGroupBox(self.horizontalLayoutWidget)
        self.rateBox.setObjectName("rateBox")
        self.formLayoutWidget_13 = QtWidgets.QWidget(self.rateBox)
        self.formLayoutWidget_13.setGeometry(QtCore.QRect(9, 27, 271, 141))
        self.formLayoutWidget_13.setObjectName("formLayoutWidget_13")
        self.formLayout_15 = QtWidgets.QFormLayout(self.formLayoutWidget_13)
        self.formLayout_15.setContentsMargins(0, 0, 0, 0)
        self.formLayout_15.setObjectName("formLayout_15")
        self.netemRateName = QtWidgets.QLabel(self.formLayoutWidget_13)
        self.netemRateName.setStatusTip("")
        self.netemRateName.setObjectName("netemRateName")
        self.formLayout_15.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.netemRateName)
        self.netemRateBox = QtWidgets.QComboBox(self.formLayoutWidget_13)
        self.netemRateBox.setObjectName("netemRateBox")
        self.formLayout_15.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.netemRateBox)
        self.netemOverheadName = QtWidgets.QLabel(self.formLayoutWidget_13)
        self.netemOverheadName.setStatusTip("")
        self.netemOverheadName.setObjectName("netemOverheadName")
        self.formLayout_15.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.netemOverheadName)
        self.netemOverheadValue = QtWidgets.QSpinBox(self.formLayoutWidget_13)
        self.netemOverheadValue.setToolTip("")
        self.netemOverheadValue.setMinimum(-100)
        self.netemOverheadValue.setMaximum(100)
        self.netemOverheadValue.setSingleStep(1)
        self.netemOverheadValue.setProperty("value", 0)
        self.netemOverheadValue.setObjectName("netemOverheadValue")
        self.formLayout_15.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.netemOverheadValue)
        self.tcBox.addWidget(self.rateBox)
        self.reorderBox_3 = QtWidgets.QGroupBox(self.horizontalLayoutWidget)
        self.reorderBox_3.setObjectName("reorderBox_3")
        self.formLayoutWidget_11 = QtWidgets.QWidget(self.reorderBox_3)
        self.formLayoutWidget_11.setGeometry(QtCore.QRect(10, 21, 243, 92))
        self.formLayoutWidget_11.setObjectName("formLayoutWidget_11")
        self.formLayout_13 = QtWidgets.QFormLayout(self.formLayoutWidget_11)
        self.formLayout_13.setContentsMargins(0, 0, 0, 0)
        self.formLayout_13.setObjectName("formLayout_13")
        self.corruptName = QtWidgets.QLabel(self.formLayoutWidget_11)
        self.corruptName.setStatusTip("")
        self.corruptName.setObjectName("corruptName")
        self.formLayout_13.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.corruptName)
        self.corruptValue = QtWidgets.QSpinBox(self.formLayoutWidget_11)
        self.corruptValue.setToolTip("")
        self.corruptValue.setMaximum(100)
        self.corruptValue.setSingleStep(1)
        self.corruptValue.setProperty("value", 0)
        self.corruptValue.setObjectName("corruptValue")
        self.formLayout_13.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.corruptValue)
        self.corrupt_correlationName = QtWidgets.QLabel(self.formLayoutWidget_11)
        self.corrupt_correlationName.setStatusTip("")
        self.corrupt_correlationName.setObjectName("corrupt_correlationName")
        self.formLayout_13.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.corrupt_correlationName)
        self.corrupt_correlationValue = QtWidgets.QSpinBox(self.formLayoutWidget_11)
        self.corrupt_correlationValue.setToolTip("")
        self.corrupt_correlationValue.setMaximum(100)
        self.corrupt_correlationValue.setSingleStep(1)
        self.corrupt_correlationValue.setProperty("value", 0)
        self.corrupt_correlationValue.setObjectName("corrupt_correlationValue")
        self.formLayout_13.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.corrupt_correlationValue)
        self.tcBox.addWidget(self.reorderBox_3)
        self.horizontalLayoutWidget_2 = QtWidgets.QWidget(self.centralwidget)
        self.horizontalLayoutWidget_2.setGeometry(QtCore.QRect(40, 100, 881, 171))
        self.horizontalLayoutWidget_2.setObjectName("horizontalLayoutWidget_2")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.horizontalLayoutWidget_2)
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.netemBox = QtWidgets.QGroupBox(self.horizontalLayoutWidget_2)
        self.netemBox.setObjectName("netemBox")
        self.formLayoutWidget = QtWidgets.QWidget(self.netemBox)
        self.formLayoutWidget.setGeometry(QtCore.QRect(10, 21, 253, 165))
        self.formLayoutWidget.setObjectName("formLayoutWidget")
        self.formLayout = QtWidgets.QFormLayout(self.formLayoutWidget)
        self.formLayout.setContentsMargins(0, 0, 0, 0)
        self.formLayout.setObjectName("formLayout")
        self.delayName = QtWidgets.QLabel(self.formLayoutWidget)
        self.delayName.setStatusTip("")
        self.delayName.setObjectName("delayName")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.delayName)
        self.jitterName = QtWidgets.QLabel(self.formLayoutWidget)
        self.jitterName.setStatusTip("")
        self.jitterName.setObjectName("jitterName")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.jitterName)
        self.jitterValue = QtWidgets.QSpinBox(self.formLayoutWidget)
        self.jitterValue.setToolTip("")
        self.jitterValue.setMaximum(500)
        self.jitterValue.setSingleStep(10)
        self.jitterValue.setProperty("value", 0)
        self.jitterValue.setObjectName("jitterValue")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.jitterValue)
        self.correlationName = QtWidgets.QLabel(self.formLayoutWidget)
        self.correlationName.setStatusTip("")
        self.correlationName.setObjectName("correlationName")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.correlationName)
        self.delay_jitter_corrValue = QtWidgets.QSpinBox(self.formLayoutWidget)
        self.delay_jitter_corrValue.setToolTip("")
        self.delay_jitter_corrValue.setMaximum(100)
        self.delay_jitter_corrValue.setSingleStep(1)
        self.delay_jitter_corrValue.setProperty("value", 0)
        self.delay_jitter_corrValue.setObjectName("delay_jitter_corrValue")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.delay_jitter_corrValue)
        self.delayValue = QtWidgets.QSpinBox(self.formLayoutWidget)
        self.delayValue.setToolTip("")
        self.delayValue.setMaximum(5000)
        self.delayValue.setSingleStep(10)
        self.delayValue.setProperty("value", 0)
        self.delayValue.setObjectName("delayValue")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.delayValue)
        self.horizontalLayout_2.addWidget(self.netemBox)
        self.lossBox_3 = QtWidgets.QGroupBox(self.horizontalLayoutWidget_2)
        self.lossBox_3.setObjectName("lossBox_3")
        self.formLayoutWidget_10 = QtWidgets.QWidget(self.lossBox_3)
        self.formLayoutWidget_10.setGeometry(QtCore.QRect(10, 21, 244, 92))
        self.formLayoutWidget_10.setObjectName("formLayoutWidget_10")
        self.formLayout_12 = QtWidgets.QFormLayout(self.formLayoutWidget_10)
        self.formLayout_12.setContentsMargins(0, 0, 0, 0)
        self.formLayout_12.setObjectName("formLayout_12")
        self.duplName = QtWidgets.QLabel(self.formLayoutWidget_10)
        self.duplName.setStatusTip("")
        self.duplName.setObjectName("duplName")
        self.formLayout_12.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.duplName)
        self.duplValue = QtWidgets.QSpinBox(self.formLayoutWidget_10)
        self.duplValue.setToolTip("")
        self.duplValue.setMaximum(100)
        self.duplValue.setSingleStep(1)
        self.duplValue.setProperty("value", 0)
        self.duplValue.setObjectName("duplValue")
        self.formLayout_12.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.duplValue)
        self.dupl_correlationName = QtWidgets.QLabel(self.formLayoutWidget_10)
        self.dupl_correlationName.setStatusTip("")
        self.dupl_correlationName.setObjectName("dupl_correlationName")
        self.formLayout_12.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.dupl_correlationName)
        self.dupl_correlationValue = QtWidgets.QSpinBox(self.formLayoutWidget_10)
        self.dupl_correlationValue.setToolTip("")
        self.dupl_correlationValue.setMaximum(100)
        self.dupl_correlationValue.setSingleStep(1)
        self.dupl_correlationValue.setProperty("value", 0)
        self.dupl_correlationValue.setObjectName("dupl_correlationValue")
        self.formLayout_12.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.dupl_correlationValue)
        self.horizontalLayout_2.addWidget(self.lossBox_3)
        self.lossBox = QtWidgets.QGroupBox(self.horizontalLayoutWidget_2)
        self.lossBox.setObjectName("lossBox")
        self.formLayoutWidget_3 = QtWidgets.QWidget(self.lossBox)
        self.formLayoutWidget_3.setGeometry(QtCore.QRect(10, 21, 243, 92))
        self.formLayoutWidget_3.setObjectName("formLayoutWidget_3")
        self.formLayout_4 = QtWidgets.QFormLayout(self.formLayoutWidget_3)
        self.formLayout_4.setContentsMargins(0, 0, 0, 0)
        self.formLayout_4.setObjectName("formLayout_4")
        self.lossName = QtWidgets.QLabel(self.formLayoutWidget_3)
        self.lossName.setStatusTip("")
        self.lossName.setObjectName("lossName")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.lossName)
        self.lossValue = QtWidgets.QSpinBox(self.formLayoutWidget_3)
        self.lossValue.setToolTip("")
        self.lossValue.setMaximum(100)
        self.lossValue.setSingleStep(1)
        self.lossValue.setProperty("value", 0)
        self.lossValue.setObjectName("lossValue")
        self.formLayout_4.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.lossValue)
        self.loss_corellationName = QtWidgets.QLabel(self.formLayoutWidget_3)
        self.loss_corellationName.setStatusTip("")
        self.loss_corellationName.setObjectName("loss_corellationName")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.loss_corellationName)
        self.loss_corellationValue = QtWidgets.QSpinBox(self.formLayoutWidget_3)
        self.loss_corellationValue.setToolTip("")
        self.loss_corellationValue.setMaximum(100)
        self.loss_corellationValue.setSingleStep(1)
        self.loss_corellationValue.setProperty("value", 0)
        self.loss_corellationValue.setObjectName("loss_corellationValue")
        self.formLayout_4.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.loss_corellationValue)
        self.horizontalLayout_2.addWidget(self.lossBox)
        self.resetButton = QtWidgets.QPushButton(self.centralwidget)
        self.resetButton.setGeometry(QtCore.QRect(730, 771, 104, 36))
        self.resetButton.setObjectName("resetButton")
        self.gridLayoutWidget = QtWidgets.QWidget(self.centralwidget)
        self.gridLayoutWidget.setGeometry(QtCore.QRect(190, 450, 291, 80))
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.source = QtWidgets.QGridLayout(self.gridLayoutWidget)
        self.source.setContentsMargins(0, 0, 0, 0)
        self.source.setObjectName("source")
        self.sourcePort = QtWidgets.QLabel(self.gridLayoutWidget)
        self.sourcePort.setObjectName("sourcePort")
        self.source.addWidget(self.sourcePort, 1, 0, 1, 1)
        self.sourceNetworkLine = QtWidgets.QLineEdit(self.gridLayoutWidget)
        self.sourceNetworkLine.setObjectName("sourceNetworkLine")
        self.source.addWidget(self.sourceNetworkLine, 0, 1, 1, 1)
        self.sourcePortLine = QtWidgets.QLineEdit(self.gridLayoutWidget)
        self.sourcePortLine.setObjectName("sourcePortLine")
        self.source.addWidget(self.sourcePortLine, 1, 1, 1, 1)
        self.sourceNetwork = QtWidgets.QLabel(self.gridLayoutWidget)
        self.sourceNetwork.setObjectName("sourceNetwork")
        self.source.addWidget(self.sourceNetwork, 0, 0, 1, 1)
        self.gridLayoutWidget_2 = QtWidgets.QWidget(self.centralwidget)
        self.gridLayoutWidget_2.setGeometry(QtCore.QRect(490, 450, 291, 80))
        self.gridLayoutWidget_2.setObjectName("gridLayoutWidget_2")
        self.destination = QtWidgets.QGridLayout(self.gridLayoutWidget_2)
        self.destination.setContentsMargins(0, 0, 0, 0)
        self.destination.setObjectName("destination")
        self.destinationNetwork = QtWidgets.QLabel(self.gridLayoutWidget_2)
        self.destinationNetwork.setObjectName("destinationNetwork")
        self.destination.addWidget(self.destinationNetwork, 0, 0, 1, 1)
        self.destinationNetworkLine = QtWidgets.QLineEdit(self.gridLayoutWidget_2)
        self.destinationNetworkLine.setObjectName("destinationNetworkLine")
        self.destination.addWidget(self.destinationNetworkLine, 0, 1, 1, 1)
        self.destinationPort = QtWidgets.QLabel(self.gridLayoutWidget_2)
        self.destinationPort.setObjectName("destinationPort")
        self.destination.addWidget(self.destinationPort, 1, 0, 1, 1)
        self.destinationPortLine = QtWidgets.QLineEdit(self.gridLayoutWidget_2)
        self.destinationPortLine.setObjectName("destinationPortLine")
        self.destination.addWidget(self.destinationPortLine, 1, 1, 1, 1)
        self.gridLayoutWidget_3 = QtWidgets.QWidget(self.centralwidget)
        self.gridLayoutWidget_3.setGeometry(QtCore.QRect(490, 530, 291, 80))
        self.gridLayoutWidget_3.setObjectName("gridLayoutWidget_3")
        self.destination_3 = QtWidgets.QGridLayout(self.gridLayoutWidget_3)
        self.destination_3.setContentsMargins(0, 0, 0, 0)
        self.destination_3.setObjectName("destination_3")
        self.destinationNetwork_3 = QtWidgets.QLabel(self.gridLayoutWidget_3)
        self.destinationNetwork_3.setObjectName("destinationNetwork_3")
        self.destination_3.addWidget(self.destinationNetwork_3, 0, 0, 1, 1)
        self.destinationNetworkLineE = QtWidgets.QLineEdit(self.gridLayoutWidget_3)
        self.destinationNetworkLineE.setObjectName("destinationNetworkLineE")
        self.destination_3.addWidget(self.destinationNetworkLineE, 0, 1, 1, 1)
        self.destinationPort_3 = QtWidgets.QLabel(self.gridLayoutWidget_3)
        self.destinationPort_3.setObjectName("destinationPort_3")
        self.destination_3.addWidget(self.destinationPort_3, 1, 0, 1, 1)
        self.destinationPortLineE = QtWidgets.QLineEdit(self.gridLayoutWidget_3)
        self.destinationPortLineE.setObjectName("destinationPortLineE")
        self.destination_3.addWidget(self.destinationPortLineE, 1, 1, 1, 1)
        self.gridLayoutWidget_4 = QtWidgets.QWidget(self.centralwidget)
        self.gridLayoutWidget_4.setGeometry(QtCore.QRect(190, 530, 291, 80))
        self.gridLayoutWidget_4.setObjectName("gridLayoutWidget_4")
        self.source_3 = QtWidgets.QGridLayout(self.gridLayoutWidget_4)
        self.source_3.setContentsMargins(0, 0, 0, 0)
        self.source_3.setObjectName("source_3")
        self.sourcePort_3 = QtWidgets.QLabel(self.gridLayoutWidget_4)
        self.sourcePort_3.setObjectName("sourcePort_3")
        self.source_3.addWidget(self.sourcePort_3, 1, 0, 1, 1)
        self.sourceNetworkLineE = QtWidgets.QLineEdit(self.gridLayoutWidget_4)
        self.sourceNetworkLineE.setObjectName("sourceNetworkLineE")
        self.source_3.addWidget(self.sourceNetworkLineE, 0, 1, 1, 1)
        self.sourcePortLineE = QtWidgets.QLineEdit(self.gridLayoutWidget_4)
        self.sourcePortLineE.setObjectName("sourcePortLineE")
        self.source_3.addWidget(self.sourcePortLineE, 1, 1, 1, 1)
        self.sourceNetwork_3 = QtWidgets.QLabel(self.gridLayoutWidget_4)
        self.sourceNetwork_3.setObjectName("sourceNetwork_3")
        self.source_3.addWidget(self.sourceNetwork_3, 0, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.centralwidget)
        self.label.setGeometry(QtCore.QRect(100, 470, 67, 19))
        self.label.setObjectName("label")
        self.label_2 = QtWidgets.QLabel(self.centralwidget)
        self.label_2.setGeometry(QtCore.QRect(100, 560, 67, 19))
        self.label_2.setObjectName("label_2")
        self.label_3 = QtWidgets.QLabel(self.centralwidget)
        self.label_3.setGeometry(QtCore.QRect(590, 40, 131, 19))
        self.label_3.setObjectName("label_3")
        self.rulesetBox = QtWidgets.QComboBox(self.centralwidget)
        self.rulesetBox.setGeometry(QtCore.QRect(730, 32, 126, 37))
        self.rulesetBox.setObjectName("rulesetBox")
        self.rulesetBox.addItem("")
        self.rulesetBox.addItem("")
        self.directionBox = QtWidgets.QComboBox(self.centralwidget)
        self.directionBox.setGeometry(QtCore.QRect(350, 29, 126, 37))
        self.directionBox.setObjectName("directionBox")
        self.directionBox.addItem("")
        self.directionBox.addItem("")
        self.directionBox.addItem("")
        WEnux.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(WEnux)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 983, 29))
        self.menubar.setObjectName("menubar")
        WEnux.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(WEnux)
        self.statusbar.setObjectName("statusbar")
        WEnux.setStatusBar(self.statusbar)

        self.retranslateUi(WEnux)
        QtCore.QMetaObject.connectSlotsByName(WEnux)

    def retranslateUi(self, WEnux):
        _translate = QtCore.QCoreApplication.translate
        WEnux.setWindowTitle(_translate("WEnux", "WEnux"))
        self.submitButton.setText(_translate("WEnux", "Submit"))
        self.interfaceLabel.setText(_translate("WEnux", "Interface"))
        self.directionLabel.setText(_translate("WEnux", "Direction"))
        self.debugBox.setText(_translate("WEnux", "Debug"))
        self.reorderBox.setTitle(_translate("WEnux", "Reorder"))
        self.reorderName.setToolTip(_translate("WEnux", "Ratio of packet reordering in a stream"))
        self.reorderName.setText(_translate("WEnux", "Reordering"))
        self.reorderValue.setSuffix(_translate("WEnux", " %"))
        self.reorder_correlationName.setToolTip(_translate("WEnux", "Correlation factor for the reorder ratio"))
        self.reorder_correlationName.setText(_translate("WEnux", "Correlation"))
        self.reorder_correlationValue.setSuffix(_translate("WEnux", " %  "))
        self.rateBox.setTitle(_translate("WEnux", "Rate"))
        self.netemRateName.setToolTip(_translate("WEnux", "Overall delay for each packet in ms"))
        self.netemRateName.setText(_translate("WEnux", "Limit"))
        self.netemOverheadName.setToolTip(_translate("WEnux", "Overhead of packet in bytes - positive value can serve as emulation of higher link layer headers, negative value can artificially strip the Ethernet header and/or simulate a link layer header\n"
"compression scheme"))
        self.netemOverheadName.setText(_translate("WEnux", "Ovearhead"))
        self.netemOverheadValue.setSuffix(_translate("WEnux", " B"))
        self.reorderBox_3.setTitle(_translate("WEnux", "Corruption"))
        self.corruptName.setToolTip(_translate("WEnux", "Ratio of insertion of invalid packets to a stream"))
        self.corruptName.setText(_translate("WEnux", "Corruption"))
        self.corruptValue.setSuffix(_translate("WEnux", " %"))
        self.corrupt_correlationName.setToolTip(_translate("WEnux", "Correlation factor for the corruption ratio"))
        self.corrupt_correlationName.setText(_translate("WEnux", "Correlation"))
        self.corrupt_correlationValue.setSuffix(_translate("WEnux", " %  "))
        self.netemBox.setTitle(_translate("WEnux", "Delay"))
        self.delayName.setToolTip(_translate("WEnux", "Overall delay for each packet in ms"))
        self.delayName.setText(_translate("WEnux", "Delay"))
        self.jitterName.setToolTip(_translate("WEnux", "Jitter in ms"))
        self.jitterName.setText(_translate("WEnux", "Jitter"))
        self.jitterValue.setSuffix(_translate("WEnux", " ms"))
        self.correlationName.setToolTip(_translate("WEnux", "Correlation factor for the random jitter"))
        self.correlationName.setText(_translate("WEnux", "Correlation"))
        self.delay_jitter_corrValue.setSuffix(_translate("WEnux", " %  "))
        self.delayValue.setSuffix(_translate("WEnux", " ms"))
        self.lossBox_3.setTitle(_translate("WEnux", "Duplication"))
        self.duplName.setToolTip(_translate("WEnux", "Percentage of packet to be duplicated"))
        self.duplName.setText(_translate("WEnux", "Duplication"))
        self.duplValue.setSuffix(_translate("WEnux", " %"))
        self.dupl_correlationName.setToolTip(_translate("WEnux", "Correlation factor for the random loss ratio"))
        self.dupl_correlationName.setText(_translate("WEnux", "Correlation"))
        self.dupl_correlationValue.setSuffix(_translate("WEnux", " %  "))
        self.lossBox.setTitle(_translate("WEnux", "Loss"))
        self.lossName.setToolTip(_translate("WEnux", "Percentage of packet to be dropped"))
        self.lossName.setText(_translate("WEnux", "Loss"))
        self.lossValue.setSuffix(_translate("WEnux", " %"))
        self.loss_corellationName.setToolTip(_translate("WEnux", "Correlation factor for the random loss ratio"))
        self.loss_corellationName.setText(_translate("WEnux", "Correlation"))
        self.loss_corellationValue.setSuffix(_translate("WEnux", " %  "))
        self.resetButton.setText(_translate("WEnux", "Reset"))
        self.sourcePort.setText(_translate("WEnux", "Source Port"))
        self.sourceNetworkLine.setText(_translate("WEnux", "0/0, ::/0"))
        self.sourceNetwork.setText(_translate("WEnux", "Source Network"))
        self.destinationNetwork.setText(_translate("WEnux", "Destination Network"))
        self.destinationPort.setText(_translate("WEnux", "Destination Port"))
        self.destinationNetwork_3.setText(_translate("WEnux", "Destination Network"))
        self.destinationPort_3.setText(_translate("WEnux", "Destination Port"))
        self.destinationPortLineE.setText(_translate("WEnux", "22"))
        self.sourcePort_3.setText(_translate("WEnux", "Source Port"))
        self.sourcePortLineE.setText(_translate("WEnux", "22"))
        self.sourceNetwork_3.setText(_translate("WEnux", "Source Network"))
        self.label.setText(_translate("WEnux", "Include"))
        self.label_2.setText(_translate("WEnux", "Exclude"))
        self.label_3.setText(_translate("WEnux", "Predefined rulesets"))
        self.rulesetBox.setItemText(0, _translate("WEnux", "None"))
        self.rulesetBox.setItemText(1, _translate("WEnux", "Unreliable 100 Mb link"))
        self.directionBox.setItemText(0, _translate("WEnux", "Egress"))
        self.directionBox.setItemText(1, _translate("WEnux", "Ingress"))
        self.directionBox.setItemText(2, _translate("WEnux", "Bidirectional"))
